@@ -83,7 +83,8 @@ Kwave::Plugin::Plugin(const PluginContext &c)
      m_progress_lock(QMutex::Recursive)
 {
     connect(&m_progress_timer, SIGNAL(timeout()),
-            this, SLOT(updateProgressTick()));
+            this, SLOT(updateProgressTick()),
+            Qt::QueuedConnection);
 }
 
 //***************************************************************************
@@ -111,8 +112,8 @@ Kwave::Plugin::~Plugin()
 	}
     }
 
-    if (m_confirm_cancel) delete m_confirm_cancel;
-    if (m_progress)       delete m_progress;
+    // finally get rid of the confirm/cancel proxy and the progress dialog
+    closeProgressDialog(this);
 }
 
 //***************************************************************************
@@ -326,6 +327,10 @@ int Kwave::Plugin::execute(QStringList &params)
     Q_ASSERT(m_thread);
     if (!m_thread) return -ENOMEM;
 
+    // increment the use count, it is decremented at the end of
+    // the run_wrapper when the thread is finished
+    use();
+
     // start the thread, this executes run()
     m_thread->start();
 
@@ -379,6 +384,7 @@ void Kwave::Plugin::close()
 	Q_ASSERT(this->thread() == QThread::currentThread());
 	Q_ASSERT(this->thread() == qApp->thread());
 
+	QMutexLocker lock(&m_progress_lock);
 	m_progress_timer.stop();
 	qApp->sendPostedEvents();
 	qApp->processEvents();
@@ -394,6 +400,7 @@ void Kwave::Plugin::close()
 void Kwave::Plugin::use()
 {
     QMutexLocker lock(&m_usage_lock);
+    Q_ASSERT(m_usage_count); // should be at least 1 (from constructor)
     m_usage_count++;
 }
 
